@@ -66,10 +66,10 @@ class GradeNotebooks():
 class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                                tornado.auth.GoogleOAuth2Mixin):
     async def get(self):
-        log.write_logs("3.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        log.write_logs("4.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')    
+        log.write_logs("1.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("2.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')    
         if not self.get_argument('code', False):
-            log.write_logs("5.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            log.write_logs("3.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
             self.authorize_redirect(
                 redirect_uri='http://grader-dev.data8x.berkeley.edu/login',
                 client_id=self.settings['google_oauth']['key'],
@@ -82,24 +82,24 @@ class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                         redirect_uri='http://grader-dev.data8x.berkeley.edu/login',
                         code=self.get_argument('code'))
         # Save the user with e.g. set_secure_cookie
-        log.write_logs("6.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("4.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         self.set_secure_cookie("user", str(user))
 
-        log.write_logs("7.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("5.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         self.redirect("/")
     
-class Userform(BaseHandler, tornado.web.RequestHandler,
-                               tornado.auth.GoogleOAuth2Mixin):
+class Userform(BaseHandler, tornado.web.RequestHandler):
+    @tornado.web.authenticated
     async def get(self):
-        c = self.get_secure_cookie("user")
-        log.write_logs("1.", str(c), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        log.write_logs("2.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        # c = self.get_secure_cookie("user")
+        # log.write_logs("1.", str(c), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        # log.write_logs("2.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         
-        if not self.get_current_user():
-            self.redirect("/login")
-            return
+        # if not self.get_current_user():
+        #     self.redirect("/login")
+        #     return
         
-        log.write_logs("9.", "Authenticated!", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("6.", "Authenticated!", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         self.render("index.html",  message=None)
 
             
@@ -177,7 +177,8 @@ settings = {
     "cookie_secret": str(uuid.uuid4()),
     "google_oauth" : {
         "key": os.environ.get("OAUTH_CLIENT_ID"),
-        "secret": os.environ.get("OAUTH_SECRET")
+        "secret": os.environ.get("OAUTH_SECRET"),
+        "login_url": "/login",
     }
 }
 application = tornado.web.Application([
